@@ -1,20 +1,19 @@
 /*
- *  Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
- *  Copyright © 2007 Christian Persch
+ * Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
+ * Copyright © 2007 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope game it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -1008,11 +1007,13 @@ scm_delayed_call (SCM callback)
 static void
 cscm_init (void)
 {
+#ifdef GUILE_DEBUG
   /* Enable useful debugging options. */
   SCM_DEVAL_P = 1;
   SCM_BACKTRACE_P = 1;
   SCM_RECORD_POSITIONS_P = 1;
   SCM_RESET_DEBUG_MODE;
+#endif
 
   /* Let the scheme side of things know about our C functions. */
   scm_c_define_gsubr ("set-feature-word!", 1, 0, 0, scm_set_feature_word);
