@@ -34,7 +34,6 @@
 #include <libgames-support/games-help.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.h>
-#include <libgames-support/games-sound.h>
 #include <libgames-support/games-stock.h>
 
 #include "main.h"
@@ -890,6 +889,7 @@ setup_window (void)
   set_fullscreen_actions (FALSE);
   notebook = gtk_notebook_new ();
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
+  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
@@ -1031,7 +1031,9 @@ main (int argc, char **argv)
   if (!games_runtime_init ("gnibbles"))
     return 1;
 
+#ifdef ENABLE_SETGID
   setgid_io_init ();
+#endif
 
   context = g_option_context_new (NULL);
 
@@ -1040,7 +1042,6 @@ main (int argc, char **argv)
 #endif 
 
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
-  games_sound_add_option_group (context);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free (context);
